#
# spec file for package perl-Module-Signature
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Module-Signature
Name:           perl-Module-Signature
Version:        0.890.0
Release:        1.1
# 0.89 -> normalize -> 0.890.0
%define cpan_version 0.89
#Upstream: SUSE-Public-Domain
License:        (Artistic-1.0 OR GPL-1.0-or-later) AND CC0-1.0
Summary:        Module signature file manipulation
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/T/TI/TIMLEGGE/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(ExtUtils::MakeMaker) >= 6.36
BuildRequires:  perl(IPC::Run)
Provides:       perl(Module::Signature) = %{version}
%undefine       __perllib_provides
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  gpg
Requires:       gpg
# MANUAL END

%description
*Module::Signature* adds cryptographic authentications to CPAN
distributions, via the special _SIGNATURE_ file.

If you are a module user, all you have to do is to remember to run
'cpansign -v' (or just 'cpansign') before issuing 'perl Makefile.PL' or
'perl Build.PL'; that will ensure the distribution has not been tampered
with.

Module authors can easily add the _SIGNATURE_ file to the distribution
tarball; see NOTES below for how to do it as part of 'make dist'.

If you _really_ want to sign a distribution manually, simply add
'SIGNATURE' to _MANIFEST_, then type 'cpansign -s' immediately before 'make
dist'. Be sure to delete the _SIGNATURE_ file afterwards.

Please also see NOTES about _MANIFEST.SKIP_ issues, especially if you are
using *Module::Build* or writing your own _MANIFEST.SKIP_.

Signatures made with Module::Signature prior to version 0.82 used the SHA1
algorithm by default. SHA1 is now considered broken, and therefore module
authors are strongly encouraged to regenerate their _SIGNATURE_ files.
Users verifying old SHA1 signature files will receive a warning.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

# MANUAL BEGIN
sed -i -e 's/use inc::Module::Install/use lib q[.];\nuse inc::Module::Install/' Makefile.PL
# MANUAL END

%build
PERL_USE_UNSAFE_INC=1 perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc ANDK2020.pub AUDREYT2018.pub AUTHORS Changes NIKLASHOLM2018.pub PAUSE2022.pub README TIMLEGGE2024.pub

%changelog
* Mon Sep 16 2024 Tina Müller <timueller+perl@suse.de>
- updated to 0.890.0 (0.89)
  see /usr/share/doc/packages/perl-Module-Signature/Changes
  [Changes for 0.89 - Fri Sep 13 21:56:06 ADT 2024]
  * Replace keyserver with keyserver.ubuntu.com (haarg)
* Sun Dec 19 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.88
  see /usr/share/doc/packages/perl-Module-Signature/Changes
  [Changes for 0.88 - Sat Dec 18 11:34:44 CST 2021]
  * Update PAUSE keys to 2022. (@skaji)
* Sun Jul  5 2020 Tina Müller <timueller+perl@suse.de>
- updated to 0.87
  see /usr/share/doc/packages/perl-Module-Signature/Changes
  [Changes for 0.87 - Sat Jul  4 15:04:41 CST 2020]
  * Skip 3-verify.t on Crypt::OpenPGP installations. (@pyramation)
* Fri Jun 26 2020 Tina Müller <timueller+perl@suse.de>
- updated to 0.86
  see /usr/share/doc/packages/perl-Module-Signature/Changes
  [Changes for 0.86 - Thu Jun 25 21:06:24 CST 2020]
  * Update PAUSE and ANDK keys to 2020. (@dweekly)
  * Update documentation pertaining to SHA1. (@dweekly)
  * Fix compatibility with Crypt::OpenPGP. (@niklasholm)
* Thu Aug 30 2018 coolo@suse.com
- updated to 0.83
  see /usr/share/doc/packages/perl-Module-Signature/Changes
  [Changes for 0.83 - Wed Aug 29 17:33:12 JST 2018]
  * Update META.yml.
* Mon Aug 27 2018 coolo@suse.com
- updated to 0.82
  see /usr/share/doc/packages/perl-Module-Signature/Changes
  [Changes for 0.82 - Sun Aug 26 23:00:04 CST 2018]
  * Fix CRLF handling on Win32. (@niklasholm)
  * Default to SHA256 on new hashes as SHA1 is deprecated. (@niklasholm)
* Tue Oct  3 2017 coolo@suse.com
- patch the Makefile to build with perl 5.26
* Tue Sep  6 2016 coolo@suse.com
- updated to 0.81
  see /usr/share/doc/packages/perl-Module-Signature/Changes
* Sun Jun 12 2016 coolo@suse.com
- updated to 0.80
  see /usr/share/doc/packages/perl-Module-Signature/Changes
* Fri Jan  8 2016 chris@computersalat.de
- update changelog
  * add missing CVE tags for 0.78 changes (boo#928382)
* Tue May 19 2015 coolo@suse.com
- updated to 0.79
  see /usr/share/doc/packages/perl-Module-Signature/Changes
  [Changes for 0.79 - Mon May 18 23:02:11 CST 2015]
  * Restore "cpansign --skip" functionality.
    Contributed by: CLOOS
* Fri Apr 17 2015 coolo@suse.com
- updated to 0.78
  see /usr/share/doc/packages/perl-Module-Signature/Changes
  [Changes for 0.78 - Thu Apr  9 16:58:27 CST 2015]
  * Fix verify() use from cpanm and CPAN.pm.
    Contributed by: ANDK
  [Changes for 0.77 - Wed Apr  8 19:36:50 CST 2015]
  * Include the latest public keys of PAUSE, ANDK and AUDREYT.
  * Clarify scripts/cpansign copyright to CC0.
    Reported by: @pghmcfc
  [Changes for 0.76 - Wed Apr  8 18:05:48 CST 2015]
  * Fix signature tests by defaulting to verify(skip=>1)
    when $ENV{TEST_SIGNATURE} is true.
    Reported by: @pghmcfc
  [Changes for 0.75 - Tue Apr  7 04:56:09 CST 2015]
  Two more issues reported by John Lightsey:
  * Update ChangeLog.
  * More protection of @INC from relative paths. (CVE-2015-3409)
  Fix various issues reported by John Lightsey:
  [Changes for 0.74 - Tue Apr  7 02:39:14 CST 2015]
  Fix various issues reported by John Lightsey:
  * Fix GPG signature parsing logic. (CVE-2015-3406)
  * MANIFEST.SKIP is no longer consulted unless --skip is given. (CVE-2015-3407)
  * Properly use open() modes to avoid injection attacks. (CVE-2015-3408)
* Sun Aug  4 2013 coolo@suse.com
- fix souce url
* Wed Jul  3 2013 chris@computersalat.de
- update to 0.73
  * fix for bnc#828010 (CVE-2013-2145)
    https://bugzilla.novell.com/process_bug.cgi
    https://bugzilla.redhat.com/show_bug.cgi?id=971096
  * Properly redo the previous fix using File::Spec->file_name_is_absolute.
- [Changes for 0.72 - Wed Jun  5 23:19:02 CST 2013]
  * Only allow loading Digest::* from absolute paths in @INC,
    by ensuring they begin with \ or / characters.
    Contributed by: Florian Weimer (CVE-2013-2145)
- [Changes for 0.71 - Tue Jun  4 18:24:10 CST 2013]
  * Constrain the user-specified digest name to /^\w+\d+$/.
  * Avoid loading Digest::* from relative paths in @INC.
    Contributed by: Florian Weimer (CVE-2013-2145)
- [Changes for 0.70 - Thu Nov 29 01:45:54 CST 2012]
  * Don't check gpg version if gpg does not exist.
    This avoids unnecessary warnings during installation
    when gpg executable is not installed.
    Contributed by: Kenichi Ishigaki
- [Changes for 0.69 - Fri Nov  2 23:04:19 CST 2012]
  * Support for gpg under these alternate names:
    gpg gpg2 gnupg gnupg2
    Contributed by: Michael Schwern
* Mon Dec 19 2011 cfarrell@suse.com
- license update: CC0-1.0 and (GPL-1.0+ or Artistic-1.0)
  License purports to be CC zero, not CC-BY. Also, see the script/cpansign
  and Module/Signature (line 88+) files for Perl licenses
* Thu Dec 15 2011 coolo@suse.com
- regenerate with cpanspec to fix requires/buildrequires
* Wed Dec 14 2011 coolo@suse.com
- update to 0.68
  * Fix breakage introduced by 0.67 (Andreas König).
  * Better handling of \r (Andreas König, Zefram)
* Wed Dec 14 2011 coolo@suse.com
- fix license to be in spdx.org format
* Tue Nov 30 2010 coolo@novell.com
- switch to perl_requires macro
* Wed Sep  8 2010 chris@computersalat.de
- update to 0.66
  * Fix incompatibility with EU::Manifest 1.54 to 1.57
    (Paul Howarth) (Closes RT#61124).
* Sat Sep  4 2010 chris@computersalat.de
- update to 0.65
  * Skip MYMETA (Alexandr Ciornii)
* Sat Jul 24 2010 chris@computersalat.de
- removed UTF-8 chars from changes
* Wed Jul 21 2010 chris@computersalat.de
- update to 0.64
  * Avoid creating gnupg configuration files for the user invoking Makefile.PL
    (Closes RT#41978).
  * Correctly detect the version of gnupg on cygwin and add tests for it
    (Paul Fenwick) (Closes RT#39258).
- [Changes for 0.63 - Sun, 28 Mar 2010 04:46:27 +0100]
  * Fix diagnostic message from Makefile.PL when the user dosn't have gnupg or
    Crypt::OpenPGP (miyagawa).
- [Changes for 0.62 - Tue, 23 Mar 2010 22:17:39 +0100]
  * Change the default keyserver from the outdated pgp.mit.edu to
    pool.sks-keyservers.net.
- [Changes for 0.61 - Thu, 19 Mov 2009 00:56:41 CST]
  * Added "=encoding utf8" to POD to fix author name display.
    No functional changes.
- [Changes for 0.60 - Mon, 16 Nov 2009 22:48:54 CST]
  * LICENSING CHANGE: This compilation and all individual files in it
    are now under the nullary CC0 1.0 Universal terms:
    To the extent possible under law, <cpan@audreyt.org> has waived all
    copyright and related or neighboring rights to Module-Signature.
  * Updated Module::Install to 0.91, prompted by Florian Ragwitz.
- recreated by cpanspec 1.78
- noarch pkg
* Sat Jul 25 2009 chris@computersalat.de
- spec mods
  * removed ^----------
  * removed ^#---------
* Sat Jun 27 2009 chris@computersalat.de
- fixed deps
  o changed Digest::SHA1 to Digest::SHA
* Fri Jun 26 2009 chris@computersalat.de
- initial package 0.55
